@@ -178,6 +178,27 @@ class LabeledEnum(str, Enum):
         return hash(self._value_)
 
 
+# Add _repr_html_ after class definition to avoid Enum member name restrictions
+def _labeled_enum_repr_html(self) -> str:
+    """Return HTML representation for Jupyter notebook display.
+
+    This method is automatically called by Jupyter when displaying the object
+    as a cell output, providing a styled representation of the enum value.
+
+    Returns:
+        HTML representation of the enum value with styling.
+    """
+    enum_class = self.__class__.__name__
+    return (
+        f'<span style="color: #5294e2; font-family: monospace;">'
+        f"{enum_class}.<b>{self.name}</b></span> "
+        f'(<code>{self._value_!r}</code>: "{self.label}")'
+    )
+
+
+LabeledEnum._repr_html_ = _labeled_enum_repr_html
+
+
 class NumericTypeItem(DataItem):
     """Numeric data item
 
@@ -653,6 +674,21 @@ class BoolItem(DataItem):
         statement defined in the base item `deserialize` method"""
         return reader.read_bool()
 
+    def __set__(self, instance: DataSet, value: bool | None) -> None:
+        """Set data item's value, ensuring it's a Python bool
+
+        This override ensures that numpy.bool_ values are converted to Python bool,
+        which is necessary for compatibility with Qt APIs that strictly require
+        Python bool type (e.g., QAction.setChecked()).
+
+        Args:
+            instance: instance of the DataSet
+            value: value to set (will be converted to Python bool if not None)
+        """
+        if value is not None:
+            value = bool(value)
+        super().__set__(instance, value)
+
 
 class DateItem(DataItem):
     """DataSet data item
@@ -1079,7 +1115,20 @@ class ChoiceItem(DataItem, Generic[_T]):
         choices = self.get_prop("data", "choices", [])
         if not isinstance(choices, ItemProperty):
             values = [v for v, _k, _i in choices]
-            if value not in values:
+            # Check if value is in values, with special handling for sequences
+            # (JSON serialization converts tuples to lists, so we need to compare
+            # their content rather than using strict equality)
+            value_found = False
+            for v in values:
+                if v == value:
+                    value_found = True
+                    break
+                # If both are sequences (list/tuple), compare their content
+                if isinstance(v, (list, tuple)) and isinstance(value, (list, tuple)):
+                    if len(v) == len(value) and all(a == b for a, b in zip(v, value)):
+                        value_found = True
+                        break
+            if not value_found:
                 if raise_exception:
                     raise ValueError(
                         f"Invalid value '{value}' (valid values: {values})"
@@ -1415,8 +1464,22 @@ class DictItem(DataItem):
 
     @staticmethod
     # pylint: disable=unused-argument
-    def __dictedit(instance: DataSet, item: DataItem, value: dict, parent):
-        """Open a dictionary editor"""
+    def __dictedit(
+        instance: DataSet,
+        item: DataItem,
+        value: dict,
+        parent,
+        trigger_apply=None,
+    ):
+        """Open a dictionary editor
+
+        Args:
+            instance: DataSet instance
+            item: DataItem instance
+            value: Current dictionary value
+            parent: Parent widget
+            trigger_apply: Optional callback to trigger auto-apply
+        """
         # pylint: disable=import-outside-toplevel
         from guidata.qthelpers import exec_dialog
         from guidata.widgets.collectionseditor import CollectionsEditor
@@ -1426,8 +1489,13 @@ class DictItem(DataItem):
         if value_was_none:
             value = {}
         editor.setup(value, readonly=instance.is_readonly())
-        if exec_dialog(editor):
-            return editor.get_value()
+        result = exec_dialog(editor)
+        if result:
+            new_value = editor.get_value()
+            # Auto-apply changes if trigger function was provided
+            if trigger_apply is not None:
+                trigger_apply()
+            return new_value
         if value_was_none:
             return None
         return value
