@@ -82,6 +82,29 @@ from guidata.userconfig import UserConfig
 
 DEBUG_DESERIALIZE = False
 
+# CSS styling for HTML tables in Jupyter notebooks
+DATASET_TABLE_CSS = """
+<style>
+    .guidata-dataset-table {
+        border-collapse: collapse;
+        font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto,
+                     'Helvetica Neue', Arial, sans-serif;
+        font-size: 13px;
+        margin: 10px 0;
+    }
+    .guidata-dataset-table td {
+        border: 1px solid #dee2e6;
+        padding: 8px 12px;
+    }
+    .guidata-dataset-table tr:nth-child(even) {
+        background-color: #f8f9fa;
+    }
+    .guidata-dataset-table tr:hover {
+        background-color: #e9ecef;
+    }
+</style>
+"""
+
 if TYPE_CHECKING:
     from qtpy.QtCore import QSize
     from qtpy.QtWidgets import QDialog, QWidget
@@ -1534,6 +1557,14 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__title
 
+    def set_title(self, title: str) -> None:
+        """Set data set title
+
+        Args:
+            title (str): title
+        """
+        self.__title = title
+
     def get_comment(self) -> str | None:
         """Return data set comment
 
@@ -1542,6 +1573,14 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__comment
 
+    def set_comment(self, comment: str | None) -> None:
+        """Set data set comment
+
+        Args:
+            comment (str | None): comment
+        """
+        self.__comment = comment
+
     def get_icon(self) -> str | None:
         """Return data set icon
 
@@ -1550,6 +1589,14 @@ class DataSet(metaclass=DataSetMeta):
         """
         return self.__icon
 
+    def set_icon(self, icon: str) -> None:
+        """Set data set icon
+
+        Args:
+            icon (str): icon
+        """
+        self.__icon = icon
+
     def set_defaults(self) -> None:
         """Set default values"""
         for item in self._items:
@@ -1559,6 +1606,14 @@ class DataSet(metaclass=DataSetMeta):
         """Return string representation of the data set"""
         return self.to_string(debug=False)
 
+    def __repr__(self) -> str:
+        """Return detailed representation showing attribute names.
+
+        This is useful in interactive Python sessions to discover
+        the attribute names needed to access/modify dataset items.
+        """
+        return self.to_string(debug=True)
+
     def check(self) -> list[str]:
         """Check the dataset item values
 
@@ -1756,13 +1811,12 @@ class DataSet(metaclass=DataSetMeta):
             HTML representation
         """
         # Create the title with comment
-        html = f'<u><b style="color: blue">{self.__title}</b></u>'
+        # Use a lighter blue (#5294e2) that works well in both light and dark modes
+        html = f'<u><b style="color: #5294e2">{self.__title}</b></u>:'
 
         if self.__comment:
             # Add comment on new line, also in blue
-            html += f'<br><span style="color: blue">{self.__comment}</span>'
-
-        html += ":"
+            html += f'<br><span style="color: #5294e2">{self.__comment}</span>'
 
         # Get items for representation (excluding trailing separators)
         filtered_items = self._get_items_for_text_representation()
@@ -1812,17 +1866,35 @@ class DataSet(metaclass=DataSetMeta):
             # Get string representation of value
             value_str = item.get_string_value(self)
 
+            # Get attribute name for programmatic access
+            attr_name = item._name
+
             html += (
                 f'<tr><td style="text-align: right; vertical-align: top;">{label}:</td>'
             )
             html += (
-                f'<td style="text-align: left; padding-left: 10px;">'
-                f"{value_str}</td></tr>"
+                f'<td style="text-align: left; padding-left: 10px;">{value_str}</td>'
+            )
+            html += (
+                f'<td style="text-align: left; padding-left: 15px; '
+                f'color: #888; font-family: monospace; font-size: 0.9em;">'
+                f"({attr_name})</td></tr>"
             )
 
         html += "</table>"
         return html
 
+    def _repr_html_(self) -> str:
+        """Return HTML representation for Jupyter notebook display.
+
+        This method is automatically called by Jupyter when displaying the object
+        as a cell output, providing a rich HTML rendering of the dataset.
+
+        Returns:
+            HTML representation of the dataset with styling.
+        """
+        return DATASET_TABLE_CSS + self.to_html()
+
     def serialize(self, writer: HDF5Writer | JSONWriter | INIWriter) -> None:
         """Serialize the dataset
 
